@@ -7,7 +7,7 @@ import os
 
 
 def main():
-    version = '0.0.5'
+    version = '0.1.7'
     # Parse command line arguments
     module, args = parse_args(sys.argv, version)
     # Set path to output directory and name to append to output files
@@ -423,10 +423,10 @@ def enum_kmers(targets_path, kmers_path, k, step):
                 print(f' WARNING --- Target {header} is shorter than the desired probe length!')
             elif len(seq) >= k and seq != '':
                 target_counter += 1
-                for i in range(0, len(seq) - k + 2, step):
-                    output_file.write('>' + header.split('|')[0] + '-' + str(i + 1) + '\n')
-                    output_file.write(seq[i:i+k] + '\n')
+                for i in range(0, len(seq) - k + 1, step):
                     kmer_counter += 1
+                    output_file.write(f'>kmer_{kmer_counter}\n')
+                    output_file.write(seq[i:i+k] + '\n')
     print(f' Enumerated {"{:,}".format(kmer_counter)} k-mers from {targets_path}.')
 
 
@@ -648,7 +648,7 @@ def write_low_cov_seqs(capture_data, low_cov_path, k, min_depth, min_length):
                     if len(low_cov_seq) > min_length and len(low_cov_seq) >= k:
                         total_low_cov_counter += 1
                         low_cov_counter += 1
-                        output_file.write(f'>{header}-{low_cov_counter}\n')
+                        output_file.write(f'>{header}_position_{low_cov_start + 1}_to_{low_cov_end}\n')
                         output_file.write(low_cov_seq + '\n')
                     elif len(low_cov_seq) > min_length and len(low_cov_seq) < k:
                         window_start = low_cov_start - int((k - len(low_cov_seq)) / 2)
@@ -660,12 +660,9 @@ def write_low_cov_seqs(capture_data, low_cov_path, k, min_depth, min_length):
                             window_start = window_start - window_end + len(seq) 
                             window_end = len(seq)
                         extended_low_cov_seq = seq[window_start:window_end]
-                        #extended_low_cov_seq += seq[window_start:low_cov_start].lower()
-                        #extended_low_cov_seq += seq[low_cov_start:low_cov_end].upper()
-                        #extended_low_cov_seq += seq[low_cov_end:window_end].lower()
                         total_low_cov_counter += 1
                         low_cov_counter += 1
-                        output_file.write(f'>{header}-{low_cov_counter}\n')
+                        output_file.write(f'>{header}_position_{window_start + 1}_to_{window_end}\n')
                         output_file.write(extended_low_cov_seq + '\n')
                     low_cov_start = low_cov_end
     print(f' Wrote {total_low_cov_counter} low coverage seqs from {"{:,}".format(len(capture_data))} targets.')
